Helper for add transitions functionality in sqlalchemy
=======================================================================

.. image:: https://github.com/bigbag/sqlalchemy-state-machine/workflows/PYPI/badge.svg
   :target: https://github.com/bigbag/sqlalchemy-state-machine/actions?query=workflow%3APYPI
   :alt: GitHub Actions status
.. image:: https://img.shields.io/pypi/v/sqlalchemy-state-machine.svg
   :target: https://pypi.python.org/pypi/sqlalchemy-state-machine